//[mahjong-utils](../../../index.md)/[mahjongutils](../index.md)/[ErrorInfo](index.md)

# ErrorInfo

interface [ErrorInfo](index.md)

#### Inheritors

| |
|---|
| [HoraArgsErrorInfo](../../mahjongutils.hora/-hora-args-error-info/index.md) |
| [CommonShantenArgsErrorInfo](../../mahjongutils.shanten/-common-shanten-args-error-info/index.md) |
| [FuroChanceShantenArgsErrorInfo](../../mahjongutils.shanten/-furo-chance-shanten-args-error-info/index.md) |

## Properties

| Name | Summary |
|---|---|
| [message](message.md) | [common]<br>abstract val [message](message.md): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
